@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class BandwidthWeightingType
-  {
-    NOT_SET,
-    default_,
-    vpc_1,
-    ebs_1
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class BandwidthWeightingType { NOT_SET, default_, vpc_1, ebs_1 };
 
-namespace BandwidthWeightingTypeMapper
-{
+namespace BandwidthWeightingTypeMapper {
 AWS_EC2_API BandwidthWeightingType GetBandwidthWeightingTypeForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForBandwidthWeightingType(BandwidthWeightingType value);
-} // namespace BandwidthWeightingTypeMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace BandwidthWeightingTypeMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
