@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class BurstablePerformance
-  {
-    NOT_SET,
-    included,
-    required,
-    excluded
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class BurstablePerformance { NOT_SET, included, required, excluded };
 
-namespace BurstablePerformanceMapper
-{
+namespace BurstablePerformanceMapper {
 AWS_EC2_API BurstablePerformance GetBurstablePerformanceForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForBurstablePerformance(BurstablePerformance value);
-} // namespace BurstablePerformanceMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace BurstablePerformanceMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
