@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class Comparison
-  {
-    NOT_SET,
-    equals,
-    in
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class Comparison { NOT_SET, equals, in };
 
-namespace ComparisonMapper
-{
+namespace ComparisonMapper {
 AWS_EC2_API Comparison GetComparisonForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForComparison(Comparison value);
-} // namespace ComparisonMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace ComparisonMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
