@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class OnDemandAllocationStrategy
-  {
-    NOT_SET,
-    lowestPrice,
-    prioritized
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class OnDemandAllocationStrategy { NOT_SET, lowestPrice, prioritized };
 
-namespace OnDemandAllocationStrategyMapper
-{
+namespace OnDemandAllocationStrategyMapper {
 AWS_EC2_API OnDemandAllocationStrategy GetOnDemandAllocationStrategyForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForOnDemandAllocationStrategy(OnDemandAllocationStrategy value);
-} // namespace OnDemandAllocationStrategyMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace OnDemandAllocationStrategyMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
