@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class VerifiedAccessLogDeliveryStatusCode
-  {
-    NOT_SET,
-    success,
-    failed
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class VerifiedAccessLogDeliveryStatusCode { NOT_SET, success, failed };
 
-namespace VerifiedAccessLogDeliveryStatusCodeMapper
-{
+namespace VerifiedAccessLogDeliveryStatusCodeMapper {
 AWS_EC2_API VerifiedAccessLogDeliveryStatusCode GetVerifiedAccessLogDeliveryStatusCodeForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForVerifiedAccessLogDeliveryStatusCode(VerifiedAccessLogDeliveryStatusCode value);
-} // namespace VerifiedAccessLogDeliveryStatusCodeMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace VerifiedAccessLogDeliveryStatusCodeMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
